import sys
import math
from pony import orm
from config import * 
from model import *
import sqlite3

db_conn = sqlite3.connect('movies.db')
db_conn.row_factory = sqlite3.Row
db = db_conn.cursor()

db.executescript(open('movies-schema.sql').read())

def start_count(name,count):
    digits = math.ceil(math.log(count + 1,10))
    form = lambda c: "\r%d %s PROCESSED %.2f%%"%(c[2],name,c[1]*100.0/c[2])
    return [form,0,count]

def next_count(counter):
    counter[1] = counter[1] + 1
    display_count(counter)

def display_count(counter):
    sys.stdout.write(counter[0](counter))
    sys.stdout.flush()

def finish_count(counter):
    display_count(counter)
    sys.stdout.write('\n')
    

with orm.db_session:

    c = start_count("GENRE", orm.count(Genre.select()))
    display_count(c)
    for g in Genre.select(lambda g: True):
        next_count(c)
        db.execute("INSERT INTO Genre VALUES (?,?)",[g.id,g.name])
    finish_count(c)

    c = start_count("ACTOR", orm.count(Actor.select()))
    display_count(c)
    for a in Actor.select(lambda a: True):
        next_count(c)
        db.execute("INSERT INTO Actor VALUES (?,?,?,?,?,?)",
                   [a.id,a.name,a.dob,a.bio,a.gender,a.popularity])

    finish_count(c)

    c = start_count("DIRECTOR", orm.count(Director.select()))
    display_count(c)
    for d in Director.select(lambda a: True):
        next_count(c)
        db.execute("INSERT INTO Director VALUES (?,?,?,?,?,?)",
                   [d.id,d.name,d.dob,d.bio,d.gender,d.popularity])

    finish_count(c)

    c = start_count("MOVIE", orm.count(Movie.select()))
    display_count(c)
    for m in Movie.select(lambda a: True):
        next_count(c)
        db.execute("INSERT INTO Movie VALUES (?,?,?,?,?,?,?,?,?,?,?,?)",
                   [m.id,m.title,m.budget,m.overview,m.popularity,m.release_date,m.runtime,m.language,m.revenue,m.vote_average,m.vote_count,m.director.id if m.director else None])
        for g in m.genres:
            db.execute("INSERT INTO Genre_Movie VALUES (?,?)",[g.id,m.id])
    finish_count(c)

    c = start_count("STAR", orm.count(Star.select()))
    display_count(c)
    for s in Star.select(lambda x: True):
        next_count(c)
        db.execute("INSERT INTO Star VALUES (?,?,?,?)",[s.id,s.movie.id,s.actor.id,s.character])
    finish_count(c)


db_conn.commit()
db.close()
