import sys
import time
import math
from pony import orm
from config import *

from log import *

class Search(db.Entity):
    search_text = orm.Required(str,autostrip=True)
    performed_on = orm.Optional(datetime.datetime,nullable=True)

class ObjectRetrieval(db.Entity):
    object_id = orm.Required(int)
    object_type = orm.Required(str)
    object_name = orm.Optional(str)
    orm.PrimaryKey(object_id,object_type)
    is_referenced = orm.Required(bool)
    weight = orm.Optional(float,nullable=True)
    is_retrieved = orm.Required(bool,default=False)
    def __str__(self):
        if self.object_type == 'MOVIE':
            return "%s %7d %s (Weight: %.2f)"%(self.object_type, self.object_id, str(self.object_name),float(self.weight))
        elif self.object_type == 'ACTOR' or self.object_type == 'DIRECTOR':
            return " * %s %7d %-40s"%(self.object_type, self.object_id, str(self.object_name))
            

class Genre(db.Entity):
    id = orm.PrimaryKey(int)
    name = orm.Required(str)
    movies = orm.Set('Movie')
    def __str__(self):
        return '[Genre ' + str(self.id) + '] ' + self.name

class Director(db.Entity):
    id = orm.PrimaryKey(int)
    name = orm.Optional(str,nullable=True)
    dob = orm.Optional(datetime.date,nullable=True)
    bio = orm.Optional(str,nullable=True)
    gender = orm.Optional(int,nullable=True)
    popularity = orm.Optional(float,nullable=True)
    adult = orm.Optional(bool,nullable=True)

    movies = orm.Set('Movie')
    def __str__(self):
        return '[Director ' + str(self.id) + '] ' + self.name

class Actor(db.Entity):
    id = orm.PrimaryKey(int)
    name = orm.Optional(str,nullable=True)
    dob = orm.Optional(datetime.date,nullable=True)
    bio = orm.Optional(str,nullable=True)
    gender = orm.Optional(int,nullable=True)
    popularity = orm.Optional(float,nullable=True)
    stars = orm.Set('Star')
    adult = orm.Optional(bool,nullable=True)
    def __str__(self):
        return '[Actor ' + str(self.id) + '] ' + self.name

class Movie(db.Entity):
    id = orm.PrimaryKey(int)
    title = orm.Optional(str,nullable=True)
    overview = orm.Optional(str,nullable=True)
    title        = orm.Optional(str,nullable=True)
    budget       = orm.Optional(float,nullable=True)
    overview     = orm.Optional(str,nullable=True)
    popularity   = orm.Optional(float,nullable=True)
    release_date = orm.Optional(datetime.date,nullable=True)
    runtime      = orm.Optional(int,nullable=True)
    language     = orm.Optional(str,nullable=True)
    revenue      = orm.Optional(float,nullable=True)
    vote_average = orm.Optional(float,nullable=True)
    vote_count   = orm.Optional(int,nullable=True)
    directors = orm.Set('Director')
    genres = orm.Set('Genre')
    cast = orm.Set('Star')
    adult = orm.Optional(bool,nullable=True)
    def __str__(self):
        return '[Movie ' + str(self.id) + '] ' + self.title

class Star(db.Entity):
    movie = orm.Required('Movie')
    actor = orm.Required('Actor')
    character = orm.Optional(str)


class JSONRetrieval(db.Entity):
    object_id = orm.Required(int)
    object_type = orm.Required(str)
    is_retrieved = orm.Required(bool,default=False)

    
db.generate_mapping(create_tables=True)
